@@ -12,6 +12,8 @@ import re
 from threading import Thread
 from multiprocessing import Process, Queue
 
+# from seEvo_evolution_init import seEvoInit
+# import externalPlots as externalPlots
 from seEvo1D.seEvo_evolution_init import seEvoInit
 import seEvo1D.externalPlots as externalPlots
 
@@ -50,10 +52,10 @@ class mainFormat(qtWidget.QWidget):
         self.th_s = []
         self.s_ID = []
         
-        self._th_pg = Thread()
-        self._th_cp = Thread()
-        self._th_mw = Thread()
-        self._th_fw = Thread()
+        self._th_pg = Process()
+        self._th_cp = Process()
+        self._th_mw = Process()
+        self._th_fw = Process()
         self.createMainView()
         self._monitor = True
         self.th_monitor = Thread(target=self.monitor, args=(self.q, self.status))
@@ -128,7 +130,7 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("No file selected!", "Alert")
             return
         if all(map(lambda x: x.endswith('.npz'), fname)):
-            self._th_fw = (Thread(target=externalPlots.fitnessWave, args=(fname,)))
+            self._th_fw = (Process(target=externalPlots.fitnessWave, args=(fname,)))
             # externalPlots.fitnessWave(fname)
             self._th_fw.start()
             self.status.setText("fitness wave plot ongoing")
@@ -144,7 +146,7 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("No file selected!", "Alert")
             return
         if all(map(lambda x: x.endswith('.npz'), fname)):
-            self._th_mw = (Thread(target=externalPlots.mutationWave, args=(fname,)))
+            self._th_mw = (Process(target=externalPlots.mutationWave, args=(fname,)))
             # externalPlots.mutationWave(fname)
             self._th_mw.start()
             self.status.setText("mutation wave plot ongoing")
@@ -160,7 +162,7 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("No file selected!", "Alert")
             return
         if all(map(lambda x: x.endswith('.npz'), fname)):
-            self._th_pg = (Thread(target=externalPlots.popGrowth, args=(fname,)))
+            self._th_pg = (Process(target=externalPlots.popGrowth, args=(fname,)))
             # externalPlots.popGrowth(fname)
             self._th_pg.start()
             self.status.setText("population growth plot ongoing")
@@ -176,7 +178,7 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("No file selected!", "Alert")
             return
         if all(map(lambda x: x.endswith('.npz'), fname)):
-            self._th_cp = (Thread(target=externalPlots.combainedMutWave, args=(fname,)))
+            self._th_cp = (Process(target=externalPlots.combainedMutWave, args=(fname,)))
             # externalPlots.combainedMutWave(fname)
             self._th_cp.start()
             self.status.setText("combined mutation wave plot ongoing")
@@ -311,6 +313,12 @@ class mainFormat(qtWidget.QWidget):
         row = row + 1
         layout.addWidget(_save_params, row, 0, 1, 3)
         
+        _load_params = qtWidget.QPushButton(self)
+        _load_params.setText('Load Parameters')
+        _load_params.clicked.connect(self.loadParams)
+        row = row + 1
+        layout.addWidget(_load_params, row, 0, 1, 3)
+        
         parametersTab.setLayout(layout)
         return parametersTab
     
@@ -332,6 +340,20 @@ class mainFormat(qtWidget.QWidget):
         filepath.parent.mkdir(parents=True, exist_ok=True)  
         dfp.to_csv(filepath)  
     
+    def loadParams(self):
+        fname = qtWidget.QFileDialog.getOpenFileName(self, 'Open file', "Z://","CSV files (*.csv)")        
+        df = pd.read_csv(fname[0])
+        df = df.to_numpy()        
+    
+        self._population.setText(str(df[0,1]))
+        self._capacity.setText(str(df[1,1]))
+        self._steps.setText(str(df[2,1]))
+        self._tau.setText(str(df[3,1]))
+        self._skip.setText(str(df[4,1]))
+        self._mut_prob.setText(str(df[5,1]))
+        self._mut_effect.setText(str(df[6,1]))        
+        self._mdt_exp.setText(str(df[7,1]))
+    
     def outputTabUI(self):
         outputTabUI = qtWidget.QWidget()
         layout = qtWidget.QGridLayout()        
@@ -346,11 +368,11 @@ class mainFormat(qtWidget.QWidget):
         row = row + 1
         layout.addWidget(_mut_wave, row, 0)
         
-        _fit_wave = qtWidget.QPushButton(self)
-        _fit_wave.setText('Fitness wave plot')
-        _fit_wave.clicked.connect(self.fitWaveAction)
-        row = row + 1
-        layout.addWidget(_fit_wave, row, 0)
+        # _fit_wave = qtWidget.QPushButton(self)
+        # _fit_wave.setText('Fitness wave plot')
+        # _fit_wave.clicked.connect(self.fitWaveAction)
+        # row = row + 1
+        # layout.addWidget(_fit_wave, row, 0)
         
         _pop_growth = qtWidget.QPushButton(self)
         _pop_growth.setText('Population growth')
@@ -393,13 +415,13 @@ class mainFormat(qtWidget.QWidget):
             layout.addRow(qtWidget.QLabel("ID: " + str(i)), qtWidget.QLabel())
         
         if self._th_pg.is_alive():
-            layout.addRow(qtWidget.QLabel("population growth plot", qtWidget.QLabel()))
+            layout.addRow(qtWidget.QLabel("population growth plot"), qtWidget.QLabel())
         if self._th_cp.is_alive():
-            layout.addRow(qtWidget.QLabel("combined plot", qtWidget.QLabel()))
+            layout.addRow(qtWidget.QLabel("combined plot"), qtWidget.QLabel())
         if self._th_mw.is_alive():
-            layout.addRow(qtWidget.QLabel("mutation wave", qtWidget.QLabel()))
+            layout.addRow(qtWidget.QLabel("mutation wave"), qtWidget.QLabel())
         if self._th_fw.is_alive():
-            layout.addRow(qtWidget.QLabel("fitness wave", qtWidget.QLabel()))
+            layout.addRow(qtWidget.QLabel("fitness wave"), qtWidget.QLabel())
         
         threadTabUI.setLayout(layout)
         return threadTabUI
